@@ -4,7 +4,8 @@
 
 __author__ = """Qiusheng Wu"""
 __email__ = 'giswqs@gmail.com'
-__version__ = '1.5.1'
+__version__ = '1.5.2'
+
+from .whitebox import *
+
 
-from .whitebox_tools import WhiteboxTools
-from .wb_runner import Runner
